==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetGatewayRouteResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * A collection of values returned by getGatewayRoute.
 * @property arn ARN of the gateway route.
 * @property createdDate Creation date of the gateway route.
 * @property id The provider-assigned unique ID for this managed resource.
 * @property lastUpdatedDate Last update date of the gateway route.
 * @property meshName
 * @property meshOwner
 * @property name
 * @property resourceOwner Resource owner's AWS account ID.
 * @property specs Gateway route specification. See the `aws.appmesh.GatewayRoute` resource for details.
 * @property tags Map of tags.
 * @property virtualGatewayName
 */
public data class GetGatewayRouteResult(
    public val arn: String,
    public val createdDate: String,
    public val id: String,
    public val lastUpdatedDate: String,
    public val meshName: String,
    public val meshOwner: String,
    public val name: String,
    public val resourceOwner: String,
    public val specs: List<GetGatewayRouteSpec>,
    public val tags: Map<String, String>,
    public val virtualGatewayName: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetGatewayRouteResult):
            GetGatewayRouteResult = GetGatewayRouteResult(
            arn = javaType.arn(),
            createdDate = javaType.createdDate(),
            id = javaType.id(),
            lastUpdatedDate = javaType.lastUpdatedDate(),
            meshName = javaType.meshName(),
            meshOwner = javaType.meshOwner(),
            name = javaType.name(),
            resourceOwner = javaType.resourceOwner(),
            specs = javaType.specs().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetGatewayRouteSpec.Companion.toKotlin(args0)
                })
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            virtualGatewayName = javaType.virtualGatewayName(),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetGatewayRouteResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * A collection of values returned by getGatewayRoute.
 * @property arn ARN of the gateway route.
 * @property createdDate Creation date of the gateway route.
 * @property id The provider-assigned unique ID for this managed resource.
 * @property lastUpdatedDate Last update date of the gateway route.
 * @property meshName
 * @property meshOwner
 * @property name
 * @property resourceOwner Resource owner's AWS account ID.
 * @property specs Gateway route specification. See the `aws.appmesh.GatewayRoute` resource for details.
 * @property tags Map of tags.
 * @property virtualGatewayName
 */
public data class GetGatewayRouteResult(
    public val arn: String,
    public val createdDate: String,
    public val id: String,
    public val lastUpdatedDate: String,
    public val meshName: String,
    public val meshOwner: String,
    public val name: String,
    public val resourceOwner: String,
    public val specs: List<GetGatewayRouteSpec>,
    public val tags: Map<String, String>,
    public val virtualGatewayName: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetGatewayRouteResult): GetGatewayRouteResult = GetGatewayRouteResult(
            arn = javaType.arn(),
            createdDate = javaType.createdDate(),
            id = javaType.id(),
            lastUpdatedDate = javaType.lastUpdatedDate(),
            meshName = javaType.meshName(),
            meshOwner = javaType.meshOwner(),
            name = javaType.name(),
            resourceOwner = javaType.resourceOwner(),
            specs = javaType.specs().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetGatewayRouteSpec.Companion.toKotlin(args0)
                })
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            virtualGatewayName = javaType.virtualGatewayName(),
        )
    }
}
